@@ -59,20 +59,6 @@ class User(AbstractUser, BaseModelAbstract):
     locationLongitude = models.FloatField(
         default=0
     )
-    # KYC
-    employerName = models.CharField(db_column='employerName', max_length=255,
-                                    blank=True, null=True)
-    employerAddress = models.TextField(db_column='employerAddress',
-                                       blank=True, null=True)
-    landlordName = models.CharField(db_column='landlordName', max_length=255,
-                                    blank=True, null=True)
-    landlordAddress = models.TextField(db_column='landlordAddress',
-                                       blank=True, null=True)
-    idNumber = models.CharField(db_column='idNumber', max_length=30,
-                                blank=True, null=True)
-    idType = models.CharField(db_column='idType', max_length=50,
-                              blank=True, null=True)
-    bvn = models.CharField(max_length=11, blank=True, null=True)
 
     class Meta:
         db_table = 'Users'
