@@ -14,19 +14,30 @@ class WorkOrderService(BaseModelAbstract, models.Model):
         return self.name
 
 
+CHARGE_TYPES = (
+    ("fixed", "fixed"),
+    ("percent", "percent")
+)
+
+
 class WorkOrderServiceCategory(BaseModelAbstract, models.Model):
     service = models.ForeignKey(
         WorkOrderService, models.SET_NULL, db_column='service',
         blank=True, null=True)
     name = models.CharField(max_length=255, blank=False, null=False)
-    chargeType = models.CharField(db_column='chargeType', blank=True,
-                                  null=True, max_length=30)
-    commission = models.DecimalField(
-        max_digits=15, decimal_places=2, default=0
+    chargeType = models.CharField(db_column='chargeType', blank=False,
+                                  choices=CHARGE_TYPES, default="fixed",
+                                  null=False, max_length=15)
+    minimumServiceCharge = models.DecimalField(
+        db_column='minimumServiceCharge', max_digits=15,
+        decimal_places=2, default=1
     )
     serviceCharge = models.DecimalField(
         db_column='serviceCharge', max_digits=15,
-        decimal_places=2, default=0
+        decimal_places=2, default=1
+    )
+    commission = models.DecimalField(
+        max_digits=15, decimal_places=2, default=0
     )
     commitmentFee = models.DecimalField(
         db_column='commitmentFee', max_digits=15,
