@@ -2,6 +2,11 @@ import os, sys
 
 from dotenv import load_dotenv
 from datetime import timedelta
+import firebase_admin
+from firebase_admin import credentials
+
+from pathlib import Path
+PACKAGE_DIR = Path(__file__).resolve().parent
 
 load_dotenv()
 
@@ -160,3 +165,10 @@ SIMPLE_JWT = {
 CORS_ALLOW_ALL_ORIGINS = True
 REDIS_CONFIG_KEY = "CONFIGURATIONS"
 
+
+firebase_credentials = credentials.Certificate(PACKAGE_DIR / "firebase.json")
+firebase_admin.initialize_app(firebase_credentials)
+
+ONE_SIGNAL_APP_ID = "8bf62455-7eb2-46fb-84a3-c4a3e99d1b61"
+ONE_SIGNAL_REST_API_KEY = "MzliODFkZGUtYmRmZS00OGE1LThmM2MtYWVjNDU3ZjM5ZTA0"
+ONE_SIGNAL_USER_AUTH_KEY = "MzliODFkZGUtYmRmZS00OGE1LThmM2MtYWVjNDU3ZjM5ZTA0"
